@@ -64,20 +64,20 @@ class NumerousApp():
             if job.get('isMain', True):
                 main_job=job
                 break
-        if not main_job:
-            raise KeyError('no main job found on scenario')
-
         org_job_id = self.nc._job_id
-        main_job_id = main_job.get('id')
-        self.nc._job_id = main_job_id
-        self.nc._run_settings = None
+        if main_job:
+            main_job_id = main_job.get('id')
+            self.nc._job_id = main_job_id
+        else:
+            self.logger.warning('no main job found on scenario')
 
+        self.nc._run_settings = None
         # Prepare simulation setup
 
         self.start_time = self.nc.run_settings.start.timestamp()
         self.end_time = self.nc.run_settings.end.timestamp()
         self.appname = self.scenario['scenarioName']
-        self.allow_hibernation = self.nc.params.get('allow_hibernation', 'False')
+        self.allow_hibernation = self.nc.params.get('allow_hibernation', False)
         self.logger.info(f'allow hibernation: {self.allow_hibernation}')
         self.nc._job_id = org_job_id
 
@@ -186,6 +186,7 @@ def run_job(numerous_job=None, appname=None, max_restarts=0, model_folder="model
                           working_folder=working_folder)
 
         app.terminate = terminate
+        nc.terminate_event = terminate
         app.loop()
 
         nc.set_scenario_progress(numerous_job._exit_code.description, numerous_job._exit_code.scenariostatus,
