@@ -52,6 +52,7 @@ class NumerousBaseJob:
         self._details = ""
         # Wrapper to allow specialized instanciation of components
         self.wrapper = None
+        self.output = None
 
     def _post_init(self):  # This is called before _run_job from the app.loop method
         timeout = 120
@@ -121,6 +122,7 @@ class NumerousBaseJob:
 
     def _start(self, app) -> ExitCode:
         self.app = app
+        exit_code = ExitCode.COMPLETED
         try:
             self._post_init()
             exit_code = self.run_job()
@@ -132,12 +134,22 @@ class NumerousBaseJob:
         finally:
             self._exit_code = exit_code
             self._save_states(self._t, exit_code.description, self._details)
+            self.post_run(exit_code)
             return exit_code
 
     def run_job(self) -> ExitCode:
         #Overwrite this method to create the simplest job
         raise NotImplementedError
 
+    def handle_output(self, row):
+        if not self.output:
+            self.output = self.app.nc.new_writer(buffer_size=0)
+        self.output.write_row(row)
+
+    def post_run(self, exit_code: ExitCode):
+        if self.output:
+            self.output.close()
+
 
 class NumerousReportJob(NumerousBaseJob):
     def __init__(self):
@@ -171,7 +183,7 @@ class NumerousSimulationJob(NumerousBaseJob):
         self.logger = logging.getLogger('numerous-simulation-job')
         self.logger.setLevel(level=LOG_LEVEL)
 
-    def initialize_simulation_system(self) -> None:
+    def initialize_simulation_system(self) -> Optional[dict]:
         """
         A method that is called once model is initialized (after the first data is read).
         Can return the initial output to be saved.
@@ -203,7 +215,6 @@ class NumerousSimulationJob(NumerousBaseJob):
             self.app.terminate.wait(timeout=5)
             self.app.nc.set_scenario_progress('waiting for initial data', ScenarioStatus.INITIALZING, 0.0, force=True)
 
-            self.output = self.app.nc.new_writer(buffer_size=0)
             t_stop = self.system.end_time
             t = self._t0
 
@@ -285,7 +296,7 @@ class NumerousSimulationJob(NumerousBaseJob):
                         if "_index" not in initial_output:
                             initial_output.update({'_index': 0})
 
-                            self.output.write_row(initial_output)
+                        self.handle_output(initial_output)
 
                 try:
                     tnew, outputs = self.step(t, self.system.dt)
@@ -308,7 +319,7 @@ class NumerousSimulationJob(NumerousBaseJob):
                 # Advance time
                 t = tnew
                 # save output
-                self.output.write_row(outputs)
+                self.handle_output(outputs)
 
                 if time() - last_logged > dt_log:
                     last_logged = time()
@@ -330,7 +341,6 @@ class NumerousSimulationJob(NumerousBaseJob):
             details = {"error message": tb_str(e), "previous_data": last_data, "data at crash": data}
             exit_code = ExitCode.ERROR
         finally:
-            self.output.close()
             self.logger.warning('job terminated')
             self._t = t
             self._details = details
